summaryrefslogtreecommitdiffstats
path: root/experimental/tqtinterface/qt4/src/3rdparty/libmng/libmng.h
diff options
context:
space:
mode:
Diffstat (limited to 'experimental/tqtinterface/qt4/src/3rdparty/libmng/libmng.h')
-rw-r--r--experimental/tqtinterface/qt4/src/3rdparty/libmng/libmng.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/experimental/tqtinterface/qt4/src/3rdparty/libmng/libmng.h b/experimental/tqtinterface/qt4/src/3rdparty/libmng/libmng.h
index 2ebfce81f..035bb0e1c 100644
--- a/experimental/tqtinterface/qt4/src/3rdparty/libmng/libmng.h
+++ b/experimental/tqtinterface/qt4/src/3rdparty/libmng/libmng.h
@@ -1960,7 +1960,7 @@ MNG_EXT mng_retcode MNG_DECL mng_putchunk_unknown (mng_handle hHandle,
/* call this function if you want to extract the nth image from the list;
the first image is designated seqnr 0! */
-/* this function tqfinds the IHDR/JHDR/BASI/DHDR with the appropriate seqnr,
+/* this function finds the IHDR/JHDR/BASI/DHDR with the appropriate seqnr,
starting from the beginning of the chunk-list; this may tend to get a little
slow for animations with a large number of chunks for images near the end */
/* supplying a seqnr past the last image in the animation will return with
@@ -1970,8 +1970,8 @@ MNG_EXT mng_retcode MNG_DECL mng_getimgdata_seq (mng_handle hHandle,
mng_uint32 iCanvasstyle,
mng_getcanvasline fGetcanvasline);
-/* both the following functions will search forward to tqfind the first IDAT/JDAT,
- and then traverse back to tqfind the start of the image (IHDR,JHDR,DHDR,BASI);
+/* both the following functions will search forward to find the first IDAT/JDAT,
+ and then traverse back to find the start of the image (IHDR,JHDR,DHDR,BASI);
note that this is very fast compared to decoding the IDAT/JDAT, so there's
not really a need for optimization; either can be called from the
iterate_chunks callback when a IHDR/JHDR is encountered; for BASI/DHDR there
@@ -2110,7 +2110,7 @@ MNG_EXT mng_retcode MNG_DECL mng_updatemngsimplicity (mng_handle hHandle,
#define MNG_INVALIDINTERLACE (mng_retcode)1040 /* interlace method invalid */
#define MNG_NOTENOUGHIDAT (mng_retcode)1041 /* ran out of compressed data */
#define MNG_PLTEINDEXERROR (mng_retcode)1042 /* palette-index out-of-range */
-#define MNG_NULLNOTFOUND (mng_retcode)1043 /* couldn't tqfind null-separator*/
+#define MNG_NULLNOTFOUND (mng_retcode)1043 /* couldn't find null-separator*/
#define MNG_KEYWORDNULL (mng_retcode)1044 /* keyword cannot be empty */
#define MNG_OBJECTUNKNOWN (mng_retcode)1045 /* the object can't be found */
#define MNG_OBJECTEXISTS (mng_retcode)1046 /* the object already exists */
@@ -2137,7 +2137,7 @@ MNG_EXT mng_retcode MNG_DECL mng_updatemngsimplicity (mng_handle hHandle,
#define MNG_WRONGCHUNK (mng_retcode)2050 /* accessing the wrong chunk */
#define MNG_INVALIDENTRYIX (mng_retcode)2051 /* accessing the wrong entry */
#define MNG_NOHEADER (mng_retcode)2052 /* must have had header first */
-#define MNG_NOCORRCHUNK (mng_retcode)2053 /* can't tqfind tqparent chunk */
+#define MNG_NOCORRCHUNK (mng_retcode)2053 /* can't find tqparent chunk */
#define MNG_NOMHDR (mng_retcode)2054 /* no MNG header available */
#define MNG_IMAGETOOLARGE (mng_retcode)4097 /* input-image way too big */